@@ -1,4 +1,3 @@
-#!/usr/bin/python -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -32,9 +31,15 @@ import firmware_extract as fe
 import firmwaretools
 import firmwaretools.pycompat as pycompat
 import firmwaretools.plugins as plugins
-import firmware_addon_dell.extract_common as common
 from firmwaretools.trace_decorator import decorate, traceLog, getLog
 
+try:
+    import firmware_addon_dell.extract_common as common
+except ImportError:
+    # if firmware-addon-dell not installed or
+    # if we are on a non-rpm based system, cant really build rpms.
+    raise plugins.DisablePlugin
+
 plugin_type = (plugins.TYPE_CLI,)
 requires_api_version = "2.0"
 
@@ -115,7 +120,7 @@ class ExtractCommand(ftcommands.YumCommand):
         if base.opts.extract_topdir is not None:
             conf.extract_topdir = os.path.realpath(os.path.expanduser(base.opts.extract_topdir))
         if getattr(conf, "extract_topdir", None) is None:
-            conf.extract_topdir = os.path.join(firmwaretools.DATADIR, "firmware", "extract")
+            conf.extract_topdir = os.path.join(firmwaretools.SHAREDSTATEDIR, "firmware-extract", "extract")
 
         if base.opts.db_path is not None:
             conf.db_path = os.path.realpath(os.path.expanduser(base.opts.db_path))
@@ -234,12 +239,15 @@ def generateWork(file, logger=moduleLog):
         status['processed'] = existing.processed
         status['name'] = existing.module_name
         status['version'] = existing.module_version
-        for key, dic in modules.items():
-            if pluginsToTry.get(key) is None:
-                continue
-            if pluginsToTry[key]["version"] == dic["version"]:
-                logger.info("already processed by %s:%s" % (key,dic['version']))
-                del(pluginsToTry[key])
+        if status['processed'] and status['version'] == pluginsToTry.get(status['name'], {}).get("version",None):
+            pluginsToTry = {}
+        elif not status['processed']:
+            for key, dic in modules.items():
+                if pluginsToTry.get(key) is None:
+                    continue
+                if pluginsToTry[key]["version"] == dic["version"]:
+                    logger.info("already processed by %s:%s" % (key,dic['version']))
+                    del(pluginsToTry[key])
 
     if conf.re_extract:
         pluginsToTry = dict(extractPlugins)
@@ -301,11 +309,13 @@ def completeWork(file, status, existing, logger):
     if existing:
         if existing.module_name == status["name"] and existing.module_version == status["version"]:
             asterisk="*"
+        else:
+            existing.lastUpdate = sqlobject.DateTimeCol.now()
+
         existing.processed = status["processed"]
         existing.module_name = status["name"]
         existing.module_version = status["version"]
         existing.modules = repr(sanitizeModuleList(extractPlugins))
-        existing.lastUpdate = sqlobject.DateTimeCol.now()
     else:
         addFile(file, status, repr(sanitizeModuleList(extractPlugins)))
 
@@ -325,7 +335,7 @@ class myMeta(sqlobject.sqlmeta):
 
 class ProcessedFile(sqlobject.SQLObject):
     class sqlmeta(myMeta): pass
-    processed = sqlobject.BoolCol()  # "PROCESSED" | "UNPROCESSED"
+    processed = sqlobject.BoolCol()
     name = sqlobject.StringCol()
     module_name = sqlobject.StringCol()
     module_version = sqlobject.StringCol()
